# RingoScanner


## What is it?
RingoScanner is a framework for scanning the web for vulnerabilities.

## Usage
```python
from ringo_scanner import Scanner
Scanner(func, items).execute() # It's like a map(func, items)
```

## Authors
- [Harukawa Sayaka](https://github.com/BBleae)
